@@ -1,4 +1,5 @@
 from tqdm import tqdm,trange
+from time import time as tm
 import time
 from random import randint,choice
 # from os import *
@@ -10,7 +11,7 @@ from math import ceil
 from f61d.setu import *
 
 
-VERSION = (0,5,11)
+VERSION = (0,5,12)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -137,9 +138,9 @@ def timeit(fun):
 '''
     def wrapper(*args,**kwargs):
         
-        t1 = time.time()
+        t1 = tm()
         ret = fun(*args,**kwargs)
-        print(f'Function takes {time.time() - t1}s')
+        print(f'Function takes {tm() - t1}s')
 
         return ret
     
