@@ -1,4 +1,4 @@
-from requests import *
+from requests import get
 from random import *
 import os
 from time import time
